{%- extends config.WORKFLOWS_FILES_BASE_TEMPLATE %}

{%- block page_body %}
TODO: Example template, please remove if you do not need it.
{{_('Welcome to %(module_name)s', module_name=module_name)}}
{%- endblock %}

